braindecode.experiments package
===============================

.. automodule:: braindecode.experiments
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::

   braindecode.experiments.bcic_iv_2a
